@@ -1,5 +1,5 @@
 use std::{
-    io::{BufReader, BufRead},
+    io::{self, Write, BufReader, BufRead},
     mem,
     process::{self, Command, Stdio},
 };
@@ -10,6 +10,7 @@ use lazy_static::lazy_static;
 struct Acc {
     diags: Vec<Vec<String>>,
     footer: Vec<String>,
+    running: bool,
 }
 
 impl Acc {
@@ -17,6 +18,7 @@ impl Acc {
         Acc {
             diags: Vec::new(),
             footer: Vec::new(),
+            running: false,
         }
     }
 
@@ -25,18 +27,28 @@ impl Acc {
             static ref RE_FMT: Regex =
                 Regex::new(r"\x1b\[[^m]{0,10}m").unwrap();
             static ref RE_CRATE: Regex =
-                Regex::new(r"^   Compiling").unwrap();
+                Regex::new(r"^   Compiling ").unwrap();
+            static ref RE_DONE: Regex =
+                Regex::new(r"^     Running ").unwrap();
             static ref RE_DIAG: Regex =
                 Regex::new(r"^(error|warning)").unwrap();
             static ref RE_FOOTER: Regex =
                 Regex::new(r"^(error|warning).*(could not compile|generated .*? warning)").unwrap();
         };
 
+        if self.running {
+            self.emit(&line);
+        }
+
         let stripped = RE_FMT.replace_all(&line, "");
 
         if RE_CRATE.is_match(&stripped) {
             self.flush();
             self.emit(&line);
+        } else if RE_DONE.is_match(&stripped) {
+            self.flush();
+            self.emit(&line);
+            self.running = true;
         } else if RE_FOOTER.is_match(&stripped) {
             self.footer.push(line);
         } else {
@@ -83,10 +95,17 @@ fn main() -> Result<()> {
     loop {
         let n = output.read_line(&mut buf)
             .wrap_err("couldn't read cargo output")?;
-        if n == 0 { break; }
+        if n == 0 {
+            acc.flush();
+            break;
+        }
         acc.take_line(mem::replace(&mut buf, String::new()));
+        if acc.running {
+            io::stderr().write_all(output.buffer())?;
+            io::copy(&mut output.into_inner(), &mut io::stderr())?;
+            break;
+        }
     }
-    acc.flush();
 
     let status = cargo.wait()?;
     process::exit(status.code().unwrap_or(-1));
